Shared runtime substrate for first-party OpenAPI-based SDKs.
Summary
Functions
Build an execution context.
Execute a rendered runtime operation against a runtime client.
Execute a generic request spec without rebuilding a runtime manifest.
Build a Foundation-backed production context.
Open a streaming request for a rendered runtime operation.
Functions
@spec context(keyword()) :: Pristine.SDK.Context.t()
Build an execution context.
@spec execute(Pristine.Client.t(), Pristine.Operation.t(), keyword()) :: {:ok, term()} | {:error, term()}
Execute a rendered runtime operation against a runtime client.
@spec execute_request( Pristine.SDK.OpenAPI.Client.request_spec_t() | Pristine.SDK.OpenAPI.Client.request_t(), Pristine.SDK.Context.t(), keyword() ) :: {:ok, term()} | {:error, term()}
Execute a generic request spec without rebuilding a runtime manifest.
@spec foundation_context(keyword()) :: Pristine.SDK.Context.t()
Build a Foundation-backed production context.
@spec stream(Pristine.Client.t(), Pristine.Operation.t(), keyword()) :: {:ok, Pristine.Response.t()} | {:error, term()}
Open a streaming request for a rendered runtime operation.